==> jc-1.4.0.tar.gz: java/awt/TexturePaint.h <==
// public class java.awt.TexturePaint

// class file dependencies
// @dep_class f0542ee5ba7de307 java_awt_TexturePaint
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_TexturePaint_H_
#define _JC_java_awt_TexturePaint_H_

// Forward structure declarations
struct _jc_java_awt_PaintContext$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_awt_image_BufferedImage$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_TexturePaint$sub_refs	_jc_java_awt_TexturePaint$sub_refs;
typedef struct _jc_java_awt_TexturePaint$sub_nonrefs	_jc_java_awt_TexturePaint$sub_nonrefs;
typedef struct _jc_java_awt_TexturePaint$refs	_jc_java_awt_TexturePaint$refs;
typedef struct _jc_java_awt_TexturePaint$nonrefs	_jc_java_awt_TexturePaint$nonrefs;
typedef struct _jc_java_awt_TexturePaint$object	_jc_java_awt_TexturePaint$object;

typedef const struct _jc_java_awt_TexturePaint$vmethods	_jc_java_awt_TexturePaint$vmethods;
typedef const struct _jc_java_awt_TexturePaint$vtable	_jc_java_awt_TexturePaint$vtable;
typedef const struct _jc_java_awt_TexturePaint$vtype	_jc_java_awt_TexturePaint$vtype;

// Constructors
extern void _jc_java_awt_TexturePaint$method$_init$ab58f88991e9ce42(_jc_env *, struct _jc_java_awt_TexturePaint$object *, struct _jc_java_awt_image_BufferedImage$object *, struct _jc_java_awt_geom_Rectangle2D$object *);

// Virtual methods
extern struct _jc_object *_jc_java_awt_TexturePaint$method$createContext$a690f44ea9ada11b(_jc_env *, struct _jc_java_awt_TexturePaint$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *);
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_TexturePaint$method$getAnchorRect$a439dcdbd79be057(_jc_env *, struct _jc_java_awt_TexturePaint$object *);
extern struct _jc_java_awt_image_BufferedImage$object *_jc_java_awt_TexturePaint$method$getImage$95097b250fe55f9c(_jc_env *, struct _jc_java_awt_TexturePaint$object *);
extern jint _jc_java_awt_TexturePaint$method$getTransparency$00c86110e9bf7fbb(_jc_env *, struct _jc_java_awt_TexturePaint$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_TexturePaint$method_info$createContext$a690f44ea9ada11b;
extern _jc_method _jc_java_awt_TexturePaint$method_info$getAnchorRect$a439dcdbd79be057;
extern _jc_method _jc_java_awt_TexturePaint$method_info$getImage$95097b250fe55f9c;
extern _jc_method _jc_java_awt_TexturePaint$method_info$getTransparency$00c86110e9bf7fbb;

// Virtual methods structure
struct _jc_java_awt_TexturePaint$vmethods {
	struct _jc_object	*(*createContext$a690f44ea9ada11b)(_jc_env *, struct _jc_java_awt_TexturePaint$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *);
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getAnchorRect$a439dcdbd79be057)(_jc_env *, struct _jc_java_awt_TexturePaint$object *);
	struct _jc_java_awt_image_BufferedImage$object	*(*getImage$95097b250fe55f9c)(_jc_env *, struct _jc_java_awt_TexturePaint$object *);
	jint	(*getTransparency$00c86110e9bf7fbb)(_jc_env *, struct _jc_java_awt_TexturePaint$object *);
};

// Vtable
struct _jc_java_awt_TexturePaint$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_TexturePaint$vmethods	java_awt_TexturePaint;
};

// Vtype
struct _jc_java_awt_TexturePaint$vtype {
	_jc_type			type;
	_jc_java_awt_TexturePaint$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_TexturePaint$sub_refs {
	struct _jc_java_awt_image_BufferedImage$object	*texture;
	struct _jc_java_awt_geom_Rectangle2D$object	*anchor;
};

// Reference instance fields (object)
struct _jc_java_awt_TexturePaint$refs {
    _jc_java_awt_TexturePaint$sub_refs	java_awt_TexturePaint;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_TexturePaint$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_TexturePaint$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_TexturePaint$sub_nonrefs	java_awt_TexturePaint;
};

// Object instance structure
struct _jc_java_awt_TexturePaint$object {
	_jc_java_awt_TexturePaint$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_TexturePaint$vtype	*vtype;
	_jc_java_awt_TexturePaint$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_TexturePaint$vtype _jc_java_awt_TexturePaint$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_TexturePaint, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_TexturePaint$class_object;

#endif	/* _JC_java_awt_TexturePaint_H_ */

==> jc-1.4.6.tar.gz: java/awt/TexturePaint.h <==
// public class java.awt.TexturePaint

// class file dependencies
// @dep_class f0542ee5ba7de307 java_awt_TexturePaint
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_TexturePaint_H_
#define _JC_java_awt_TexturePaint_H_

// Forward structure declarations
struct _jc_java_awt_PaintContext$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_awt_image_BufferedImage$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_TexturePaint$sub_refs	_jc_java_awt_TexturePaint$sub_refs;
typedef struct _jc_java_awt_TexturePaint$sub_nonrefs	_jc_java_awt_TexturePaint$sub_nonrefs;
typedef struct _jc_java_awt_TexturePaint$refs	_jc_java_awt_TexturePaint$refs;
typedef struct _jc_java_awt_TexturePaint$nonrefs	_jc_java_awt_TexturePaint$nonrefs;
typedef struct _jc_java_awt_TexturePaint$object	_jc_java_awt_TexturePaint$object;

typedef const struct _jc_java_awt_TexturePaint$vmethods	_jc_java_awt_TexturePaint$vmethods;
typedef const struct _jc_java_awt_TexturePaint$vtable	_jc_java_awt_TexturePaint$vtable;
typedef const struct _jc_java_awt_TexturePaint$vtype	_jc_java_awt_TexturePaint$vtype;

// Constructors
extern void _jc_java_awt_TexturePaint$method$_init$ab58f88991e9ce42(_jc_env *, struct _jc_java_awt_TexturePaint$object *, struct _jc_java_awt_image_BufferedImage$object *, struct _jc_java_awt_geom_Rectangle2D$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_awt_TexturePaint$method$createContext$a690f44ea9ada11b(_jc_env *, struct _jc_java_awt_TexturePaint$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_TexturePaint$method$getAnchorRect$a439dcdbd79be057(_jc_env *, struct _jc_java_awt_TexturePaint$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_BufferedImage$object *_jc_java_awt_TexturePaint$method$getImage$95097b250fe55f9c(_jc_env *, struct _jc_java_awt_TexturePaint$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_TexturePaint$method$getTransparency$00c86110e9bf7fbb(_jc_env *, struct _jc_java_awt_TexturePaint$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_TexturePaint$method_info$createContext$a690f44ea9ada11b;
extern _jc_method _jc_java_awt_TexturePaint$method_info$getAnchorRect$a439dcdbd79be057;
extern _jc_method _jc_java_awt_TexturePaint$method_info$getImage$95097b250fe55f9c;
extern _jc_method _jc_java_awt_TexturePaint$method_info$getTransparency$00c86110e9bf7fbb;

// Virtual methods structure
struct _jc_java_awt_TexturePaint$vmethods {
	struct _jc_object	*(*createContext$a690f44ea9ada11b)(_jc_env *, struct _jc_java_awt_TexturePaint$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getAnchorRect$a439dcdbd79be057)(_jc_env *, struct _jc_java_awt_TexturePaint$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_image_BufferedImage$object	*(*getImage$95097b250fe55f9c)(_jc_env *, struct _jc_java_awt_TexturePaint$object *) _JC_JCNI_ATTR;
	jint	(*getTransparency$00c86110e9bf7fbb)(_jc_env *, struct _jc_java_awt_TexturePaint$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_TexturePaint$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_TexturePaint$vmethods	java_awt_TexturePaint;
};

// Vtype
struct _jc_java_awt_TexturePaint$vtype {
	_jc_type			type;
	_jc_java_awt_TexturePaint$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_TexturePaint$sub_refs {
	struct _jc_java_awt_image_BufferedImage$object	*texture;
	struct _jc_java_awt_geom_Rectangle2D$object	*anchor;
};

// Reference instance fields (object)
struct _jc_java_awt_TexturePaint$refs {
    _jc_java_awt_TexturePaint$sub_refs	java_awt_TexturePaint;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_TexturePaint$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_TexturePaint$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_TexturePaint$sub_nonrefs	java_awt_TexturePaint;
};

// Object instance structure
struct _jc_java_awt_TexturePaint$object {
	_jc_java_awt_TexturePaint$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_TexturePaint$vtype	*vtype;
	_jc_java_awt_TexturePaint$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_TexturePaint$vtype _jc_java_awt_TexturePaint$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_TexturePaint, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_TexturePaint$class_object;

#endif	/* _JC_java_awt_TexturePaint_H_ */
